==> u61-0.2.1.tar.gz: u61-0.2.1/data/dummy.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * This project is protected by the GPL, see copying.txt                    *
 *                                                                          *
 ****************************************************************************/

/* name:        dummy.cpp
 * author       U-Foot (ufoot@bigfoot.com)
 * last update: January 2000
 * description: dummy file used to compile data files 
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "dummy.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/

U61_Dummy dummy;

/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * title of the application window
 */ 
char *U61_Dummy::get_title()
{
	return "U61 Dummy by U-Foot (ufoot@bigfoot.com)";
}

/*--------------------------------------------------------------------------*/
/*
 * main function of the application
 */
int U61_Dummy::main(int /*argc*/, char** /*argv*/)
{
    return 0;
}

/*--------------------------------------------------------------------------*/
/*
 * initialization of ClanLib modules
 */
void U61_Dummy::init_modules()
{
    CL_SetupCore::init();
    //CL_SetupCore::init_display();
    //CL_SetupCore::init_sound();
}

/*--------------------------------------------------------------------------*/
/*
 * de-initialization of ClanLib modules
 */
void U61_Dummy::deinit_modules()
{
    //CL_SetupCore::deinit_sound();
    //CL_SetupCore::deinit_display();
    CL_SetupCore::deinit();
}

==> u61-0.2.2.tar.gz: u61-0.2.2/data/dummy.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * This project is protected by the GPL, see copying.txt                    *
 *                                                                          *
 ****************************************************************************/

/* name:        dummy.cpp
 * author       U-Foot (ufoot@bigfoot.com)
 * last update: January 2000
 * description: dummy file used to compile data files 
 */

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "dummy.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/

U61_Dummy dummy;

/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * title of the application window
 */ 
char *U61_Dummy::get_title()
{
  return "U61 Dummy by U-Foot (ufoot@ufoot.org)";
}

/*--------------------------------------------------------------------------*/
/*
 * main function of the application
 */
int U61_Dummy::main(int argc, char** argv)
{
  //CL_SetupCore::init();
  //CL_SetupCore::init_display();

  //CL_Display::set_videomode(100,100,16,false);
  //CL_DatafileCompiler::write(argv[1],argv[2]);

  //CL_SetupCore::deinit_display();
  //CL_SetupCore::deinit();

  return 0;
}

/*--------------------------------------------------------------------------*/
/*
 * initialization of ClanLib modules
 */
void U61_Dummy::init_modules()
{
  CL_SetupCore::init();
  //CL_SetupCore::init_display();
  //CL_SetupCore::init_sound();
}

/*--------------------------------------------------------------------------*/
/*
 * de-initialization of ClanLib modules
 */
void U61_Dummy::deinit_modules()
{
  //CL_SetupCore::deinit_sound();
  //CL_SetupCore::deinit_display();
  CL_SetupCore::deinit();
}
